Bodhi Server APIs — bodhi 4.0.0 documentation

# Bodhi Server APIs

## Message API

Bodhi sends a number of AMQP messages. Each message has a formally defined schema. Bodhi provides a convenient `bodhi.messages` Python package that allows you to interact with messages via handy Python classes. If you are unable to use Python 3.6+, Bodhi also publishes its message schemas via JSON Schema.

Warning

Bodhi’s messages do contain fields that are not documented in its JSON schemas. Bodhi does not make any guarantees about data that is not documented in its schema, and thus it is subject to change. Please work with the Bodhi project if you need data that is not part of Bodhi’s schemas.

- Base
  - Python objects
- Buildroot overrides
  - Python objects
  - JSON schemas
- Compose
  - Python objects
  - JSON schemas
- Composer
  - Python objects
  - JSON schemas
- Errata
  - Python objects
  - JSON schemas
- Update
  - Python objects
  - JSON schemas

## REST API

This section of the documentation describes Bodhi’s REST API. You can read about the various sections of the API by following the links below:

- Builds
  - Build service at /builds/{nvr}
  - Builds service at /builds/
- Comments
  - Comment service at /comments/{id}
  - Comments service at /comments/
  - Comments_Rss service at /rss/comments/
- Composes
- CSRF
  - Csrf service at /csrf
- Markdown
  - Markdowner service at /markdown
- Overrides
  - Override service at /overrides/{nvr}
  - Overrides service at /overrides/
  - Overrides_Rss service at /rss/overrides/
- Packages
  - Packages service at /packages/
- Releases
  - Release service at /releases/{name}
  - Releases service at /releases/
- Updates
  - Update service at /updates/{id}
  - Update_Edit service at /updates/{id}/edit
  - Updates service at /updates/
  - Updates_Rss service at /rss/updates/
  - Update_Request service at /updates/{id}/request
  - Update_Waive_Test_Results service at /updates/{id}/waive-test-results
  - Update_Get_Test_Results service at /updates/{id}/get-test-results
- Users
  - User service at /users/{name}
  - Users service at /users/
  - Users_Rss service at /rss/users/